imaplib.IMAP4

Module imaplib :: Class IMAP4 |
[show private | hide private]
[frames | no frames]

## Class IMAP4

Known Subclasses:
  `IMAP4_TLS`

    IMAP4 client class.

    Instantiate with: IMAP4([host[, port]])

            host - host's name (default: localhost);
            port - port number (default: standard IMAP4 port).

    All IMAP4rev1 commands are supported by methods of the same
    name (in lower-case).

    All arguments to commands are converted to strings, except for
    AUTHENTICATE, and the last argument to APPEND which is passed as
    an IMAP4 literal.  If necessary (the string contains any
    non-printing characters or white-space and isn't enclosed with
    either parentheses or double quotes) each string is quoted.
    However, the 'password' argument to the LOGIN command is always
    quoted.  If you want to avoid having an argument string quoted
    (eg: the 'flags' argument to STORE) then enclose the string in
    parentheses (eg: "(\Deleted)").

    Each command returns a tuple: (type, [data, ...]) where 'type'
    is usually 'OK' or 'NO', and 'data' is either the text from the
    tagged response, or untagged results from command. Each 'data'
    is either a string, or a tuple. If a tuple, then the first part
    is the header of the response, and the second part contains
    the data (ie: 'literal' value).

    Errors raise the exception class <instance>.error("<reason>").
    IMAP4 server errors raise <instance>.abort("<reason>"),
    which is a sub-class of 'error'. Mailbox status changes
    from READ-WRITE to READ-ONLY raise the exception class
    <instance>.readonly("<reason>"), which is a sub-class of 'abort'.

    "error" exceptions imply a program error.
    "abort" exceptions imply the connection should be reset, and
            the command re-tried.
    "readonly" exceptions imply the command should be re-tried.

    Note: to use this module, you must read the RFCs pertaining
    to the IMAP4 protocol, as the semantics of the arguments to
    each IMAP4 command are left to the invoker, not to mention
    the results.

Method Summary
| `__init__(self, host, port)`
| `__getattr__(self, attr)`
| ``append`(self, mailbox, flags, date_time, message)` Append message to named mailbox.
| ``authenticate`(self, mechanism, authobject)` Authenticate command - requires response processing.
| ``check`(self)` Checkpoint mailbox on server.
| ``close`(self)` Close currently selected mailbox.
| ``copy`(self, message_set, new_mailbox)` Copy 'message_set' messages onto end of 'new_mailbox'.
| ``create`(self, mailbox)` Create new mailbox.
| ``delete`(self, mailbox)` Delete old mailbox.
| ``expunge`(self)` Permanently remove deleted items from selected mailbox.
| ``fetch`(self, message_set, message_parts)` Fetch (parts of) messages.
| ``getacl`(self, mailbox)` Get the ACLs for a mailbox.
| ``getquota`(self, root)` Get the quota root's resource usage and limits.
| ``getquotaroot`(self, mailbox)` Get the list of quota roots for the named mailbox.
| ``list`(self, directory, pattern)` List mailbox names in directory matching pattern.
| ``login`(self, user, password)` Identify client using plaintext password.
| ``login_cram_md5`(self, user, password)` Force use of CRAM-MD5 authentication.
| ``logout`(self)` Shutdown connection to server.
| ``lsub`(self, directory, pattern)` List 'subscribed' mailbox names in directory matching pattern.
| ``namespace`(self)` Returns IMAP namespaces ala rfc2342
| ``noop`(self)` Send NOOP command.
| ``open`(self, host, port)` Setup connection to remote server on "host:port" (default: localhost:standard IMAP4 port).
| ``partial`(self, message_num, message_part, start, length)` Fetch truncated part of a message.
| `print_log(self)`
| ``proxyauth`(self, user)` Assume authentication as "user".
| ``read`(self, size)` Read 'size' bytes from remote.
| ``readline`(self)` Read line from remote.
| ``recent`(self)` Return most recent 'RECENT' responses if any exist, else prompt server for an update using the 'NOOP' command.
| ``rename`(self, oldmailbox, newmailbox)` Rename old mailbox name to new.
| ``response`(self, code)` Return data for response 'code' if received, or None.
| ``search`(self, charset, *criteria)` Search mailbox for matching messages.
| ``select`(self, mailbox, readonly)` Select a mailbox.
| ``send`(self, data)` Send data to remote.
| ``setacl`(self, mailbox, who, what)` Set a mailbox acl.
| ``setquota`(self, root, limits)` Set the quota root's resource limits.
| ``shutdown`(self)` Close I/O established in "open".
| ``socket`(self)` Return socket instance used to connect to IMAP4 server.
| ``sort`(self, sort_criteria, charset, *search_criteria)` IMAP4rev1 extension SORT command.
| ``status`(self, mailbox, names)` Request named status conditions for mailbox.
| ``store`(self, message_set, command, flags)` Alters flag dispositions for messages in mailbox.
| ``subscribe`(self, mailbox)` Subscribe to new mailbox.
| ``uid`(self, command, *args)` Execute "command arg ..." with messages identified by UID, rather than message number.
| ``unsubscribe`(self, mailbox)` Unsubscribe from old mailbox.
| ``xatom`(self, name, *args)` Allow simple extension commands notified by server in CAPABILITY response.

Class Variable Summary
`SRE_Pattern` | `mustquote` = `[^\w!#\$%&'\*\+,\.:;<=>\?\^`\|~-]`

Method Details

### append(self, mailbox, flags, date_time, message)
    Append message to named mailbox.

    (typ, [data]) = <instance>.append(mailbox, flags, date_time, message)

            All args except `message' can be None.

### authenticate(self, mechanism, authobject)
    Authenticate command - requires response processing.

    'mechanism' specifies which authentication mechanism is to
    be used - it must appear in <instance>.capabilities in the
    form AUTH=<mechanism>.

    'authobject' must be a callable object:

            data = authobject(response)

    It will be called to process server continuation responses.
    It should return data that will be encoded and sent to server.
    It should return None if the client abort response '*' should
    be sent instead.

### check(self) Checkpoint mailbox on server. (typ, [data]) = <instance>.check()

### close(self) Close currently selected mailbox. Deleted messages are removed from writable mailbox. This is the recommended command before 'LOGOUT'. (typ, [data]) = <instance>.close()

### copy(self, message_set, new_mailbox) Copy 'message_set' messages onto end of 'new_mailbox'. (typ, [data]) = <instance>.copy(message_set, new_mailbox)

### create(self, mailbox) Create new mailbox. (typ, [data]) = <instance>.create(mailbox)

### delete(self, mailbox) Delete old mailbox. (typ, [data]) = <instance>.delete(mailbox)

### expunge(self) Permanently remove deleted items from selected mailbox. Generates 'EXPUNGE' response for each deleted message. (typ, [data]) = <instance>.expunge() 'data' is list of 'EXPUNGE'd message numbers in order received.

### fetch(self, message_set, message_parts) Fetch (parts of) messages. (typ, [data, ...]) = <instance>.fetch(message_set, message_parts) 'message_parts' should be a string of selected parts enclosed in parentheses, eg: "(UID BODY[TEXT])". 'data' are tuples of message part envelope and data.

### getacl(self, mailbox) Get the ACLs for a mailbox. (typ, [data]) = <instance>.getacl(mailbox)

### getquota(self, root) Get the quota root's resource usage and limits. Part of the IMAP4 QUOTA extension defined in rfc2087. (typ, [data]) = <instance>.getquota(root)

### getquotaroot(self, mailbox) Get the list of quota roots for the named mailbox. (typ, [[QUOTAROOT responses...], [QUOTA responses]]) = <instance>.getquotaroot(mailbox)

### list(self, directory='""', pattern='*') List mailbox names in directory matching pattern. (typ, [data]) = <instance>.list(directory='""', pattern='*') 'data' is list of LIST responses.

### login(self, user, password) Identify client using plaintext password. (typ, [data]) = <instance>.login(user, password) NB: 'password' will be quoted.

### login_cram_md5(self, user, password) Force use of CRAM-MD5 authentication. (typ, [data]) = <instance>.login_cram_md5(user, password)

### logout(self) Shutdown connection to server. (typ, [data]) = <instance>.logout() Returns server 'BYE' response.

### lsub(self, directory='""', pattern='*') List 'subscribed' mailbox names in directory matching pattern. (typ, [data, ...]) = <instance>.lsub(directory='""', pattern='*') 'data' are tuples of message part envelope and data.

### namespace(self) Returns IMAP namespaces ala rfc2342 (typ, [data, ...]) = <instance>.namespace()

### noop(self) Send NOOP command. (typ, [data]) = <instance>.noop()

### open(self, host='', port=143)
    Setup connection to remote server on "host:port"
        (default: localhost:standard IMAP4 port).
    This connection will be used by the routines:
        read, readline, send, shutdown.

### partial(self, message_num, message_part, start, length) Fetch truncated part of a message. (typ, [data, ...]) = <instance>.partial(message_num, message_part, start, length) 'data' is tuple of message part envelope and data.

### proxyauth(self, user) Assume authentication as "user". Allows an authorised administrator to proxy into any user's mailbox. (typ, [data]) = <instance>.proxyauth(user)

### read(self, size) Read 'size' bytes from remote.

### readline(self) Read line from remote.

### recent(self) Return most recent 'RECENT' responses if any exist, else prompt server for an update using the 'NOOP' command. (typ, [data]) = <instance>.recent() 'data' is None if no new messages, else list of RECENT responses, most recent last.

### rename(self, oldmailbox, newmailbox) Rename old mailbox name to new. (typ, [data]) = <instance>.rename(oldmailbox, newmailbox)

### response(self, code) Return data for response 'code' if received, or None. Old value for response 'code' is cleared. (code, [data]) = <instance>.response(code)

### search(self, charset, *criteria) Search mailbox for matching messages. (typ, [data]) = <instance>.search(charset, criterion, ...) 'data' is space separated list of matching message numbers.

### select(self, mailbox='INBOX', readonly=None) Select a mailbox. Flush all untagged responses. (typ, [data]) = <instance>.select(mailbox='INBOX', readonly=None) 'data' is count of messages in mailbox ('EXISTS' response).

### send(self, data) Send data to remote.

### setacl(self, mailbox, who, what) Set a mailbox acl. (typ, [data]) = <instance>.create(mailbox, who, what)

### setquota(self, root, limits) Set the quota root's resource limits. (typ, [data]) = <instance>.setquota(root, limits)

### shutdown(self) Close I/O established in "open".

### socket(self) Return socket instance used to connect to IMAP4 server. socket = <instance>.socket()

### sort(self, sort_criteria, charset, *search_criteria) IMAP4rev1 extension SORT command. (typ, [data]) = <instance>.sort(sort_criteria, charset, search_criteria, ...)

### status(self, mailbox, names) Request named status conditions for mailbox. (typ, [data]) = <instance>.status(mailbox, names)

### store(self, message_set, command, flags) Alters flag dispositions for messages in mailbox. (typ, [data]) = <instance>.store(message_set, command, flags)

### subscribe(self, mailbox) Subscribe to new mailbox. (typ, [data]) = <instance>.subscribe(mailbox)

### uid(self, command, *args)
    Execute "command arg ..." with messages identified by UID,
            rather than message number.

    (typ, [data]) = <instance>.uid(command, arg1, arg2, ...)

    Returns response appropriate to 'command'.

### unsubscribe(self, mailbox) Unsubscribe from old mailbox. (typ, [data]) = <instance>.unsubscribe(mailbox)

### xatom(self, name, *args)
    Allow simple extension commands
            notified by server in CAPABILITY response.

    Assumes command is legal in current state.

    (typ, [data]) = <instance>.xatom(name, arg, ...)

    Returns response appropriate to extension command `name'.

Class Variable Details

    ### mustquote Type: `SRE_Pattern` Value:
        [^\w!#\$%&'\*\+,\.:;<=>\?\^`\|~-]

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net